@@ -48,8 +48,9 @@ import com.jgoodies.common.test.event.ListDataReport;
  * A test case for classes {@link ArrayListModel} and {@link LinkedListModel}.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.4 $
+ * @version $Revision: 1.6 $
  */
+@SuppressWarnings("static-method")
 public final class ObservableListTest extends TestCase {
 
     /**
@@ -448,7 +449,7 @@ public final class ObservableListTest extends TestCase {
 
     // Test Implementations **************************************************
 
-    private void testAdd(ObservableList<String> list) {
+    private static void testAdd(ObservableList<String> list) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -465,7 +466,7 @@ public final class ObservableListTest extends TestCase {
                 2, listDataReport.eventCountAdd());
     }
 
-    private void testAddIndexed(ObservableList<String> list, int index) {
+    private static void testAddIndexed(ObservableList<String> list, int index) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -491,7 +492,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testAddAll(ObservableList<E> list, List<E> additions) {
+    private static <E> void testAddAll(ObservableList<E> list, List<E> additions) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -526,7 +527,7 @@ public final class ObservableListTest extends TestCase {
         }
     }
 
-    private <E> void testAddAllIndexed(ObservableList<E> list, List<E> additions, int index) {
+    private static <E> void testAddAllIndexed(ObservableList<E> list, List<E> additions, int index) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -562,7 +563,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testClear(ObservableList<E> list) {
+    private static <E> void testClear(ObservableList<E> list) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -587,7 +588,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testRemoveIndex(ObservableList<E> list, int index) {
+    private static <E> void testRemoveIndex(ObservableList<E> list, int index) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -631,7 +632,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testRemoveObject(ObservableList<E> list, int index) {
+    private static <E> void testRemoveObject(ObservableList<E> list, int index) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -656,7 +657,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testRemoveAll(ObservableList<E> list, List<E> removals) {
+    private static <E> void testRemoveAll(ObservableList<E> list, List<E> removals) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -694,7 +695,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testRetainAll(ObservableList<E> list, List<E> retains) {
+    private static <E> void testRetainAll(ObservableList<E> list, List<E> retains) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -710,7 +711,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private void testSet(ObservableList<String> list, int index) {
+    private static void testSet(ObservableList<String> list, int index) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -754,7 +755,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private void testListIteratorAdd(ObservableList<String> list, int iteratorIndex, int elementIndex) {
+    private static void testListIteratorAdd(ObservableList<String> list, int iteratorIndex, int elementIndex) {
         ListDataReport listDataReport = new ListDataReport();
         list.addListDataListener(listDataReport);
 
@@ -776,7 +777,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testListIteratorRemove(
+    private static <E> void testListIteratorRemove(
             ObservableList<E> list,
             int iteratorIndex,
             int elementIndex) {
@@ -802,7 +803,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testListIteratorSet(
+    private static <E> void testListIteratorSet(
             ObservableList<String> list,
             int iteratorIndex,
             int elementIndex) {
@@ -828,7 +829,7 @@ public final class ObservableListTest extends TestCase {
     }
 
 
-    private <E> void testIteratorRemove(
+    private static <E> void testIteratorRemove(
             ObservableList<E> list,
             int elementIndex) {
         ListDataReport listDataReport = new ListDataReport();
@@ -853,27 +854,27 @@ public final class ObservableListTest extends TestCase {
 
     // Creating Observable Lists *********************************************
 
-    private ArrayListModel<String> createEmptyArrayListModel() {
+    private static ArrayListModel<String> createEmptyArrayListModel() {
         return new ArrayListModel<String>();
     }
 
-    private LinkedListModel<String> createEmptyLinkedListModel() {
+    private static LinkedListModel<String> createEmptyLinkedListModel() {
         return new LinkedListModel<String>();
     }
 
-    private ArrayListModel<String> createSingleElementArrayListModel() {
+    private static ArrayListModel<String> createSingleElementArrayListModel() {
         ArrayListModel<String> list = new ArrayListModel<String>();
         list.add("One");
         return list;
     }
 
-    private LinkedListModel<String> createSingleElementLinkedListModel() {
+    private static LinkedListModel<String> createSingleElementLinkedListModel() {
         LinkedListModel<String> list = new LinkedListModel<String>();
         list.add("One");
         return list;
     }
 
-    private ArrayListModel<String> createFilledArrayListModel() {
+    private static ArrayListModel<String> createFilledArrayListModel() {
         ArrayListModel<String> list = new ArrayListModel<String>();
         list.add("One");
         list.add("Two");
@@ -884,7 +885,7 @@ public final class ObservableListTest extends TestCase {
         return list;
     }
 
-    private LinkedListModel<String> createFilledLinkedListModel() {
+    private static LinkedListModel<String> createFilledLinkedListModel() {
         LinkedListModel<String> list = new LinkedListModel<String>();
         list.add("One");
         list.add("Two");
